@@ -77,23 +77,23 @@ class PropertyBox(gtk.Dialog):
         self.g_notebook.show()
         self.vbox.pack_start(self.g_notebook, gtk.FALSE)
 
-        self.g_ok = gtk.Button(stock='gtk-ok')
-        self.g_ok.connect('clicked', self._ok)
-        self.g_ok.set_sensitive(gtk.FALSE)
-        self.action_area.pack_start(self.g_ok)
+        self.g_help = gtk.Button(stock='gtk-help')
+        self.g_help.connect('clicked', self.on_help)
+        self.action_area.pack_start(self.g_help)
 
         self.g_apply = gtk.Button(stock='gtk-apply')
         self.g_apply.connect('clicked', self._apply)
         self.g_apply.set_sensitive(gtk.FALSE)
         self.action_area.pack_start(self.g_apply)
 
-        self.g_cancel = gtk.Button(stock='gtk-cancel')
-        self.g_cancel.connect('clicked', lambda widget: self.destroy())
-        self.action_area.pack_start(self.g_cancel)
+        self.g_close = gtk.Button(stock='gtk-close')
+        self.g_close.connect('clicked', lambda widget: self.destroy())
+        self.action_area.pack_start(self.g_close)
 
-        self.g_help = gtk.Button(stock='gtk-help')
-        self.g_help.connect('clicked', self.on_help)
-        self.action_area.pack_start(self.g_help)
+        self.g_ok = gtk.Button(stock='gtk-ok')
+        self.g_ok.connect('clicked', self._ok)
+        self.g_ok.set_sensitive(gtk.FALSE)
+        self.action_area.pack_start(self.g_ok)
     def connect(self, event, cb):
         if event in ('apply', 'help'):
                 pass
