@@ -71,7 +71,7 @@ def play_music(music, tempo, patch, velocity):
 ##################
 
 def transpose_notename(n, t):
-    assert type(n) == types.StringType
+    assert type(n) in types.StringTypes
     assert type(t) == types.IntType
     # 1 2 sekund
     # 3 4 ters
