@@ -34,6 +34,12 @@ def int_to_notename(i):
     p.set_from_int(i)
     return p.get_octave_notename()
 
+def int_to_user_notename(i):
+    p = MusicalPitch()
+    p.set_from_int(i)
+    return p.get_user_octave_notename()
+
+
 def notename_to_int(n):
     p = MusicalPitch.new_from_notename(n)
     return p.semitone_pitch()
