@@ -294,6 +294,15 @@ class MusicalPitch:
         notename  : as the value translated in the po file
         notename2 : lowercase, but capitalized if below the tone c (as
                     "c" is defined internally in solfege.
+        suboct :  '' (nothing) for c or higher
+                  <sub>1</sub> for c,
+                  <sub>2</sub> for c,,
+        suboct2:  '' (nothing) for c, and higher
+                  <sub>1</sub> for c,,
+                  <sub>2</sub> for c,,,
+        supoct:   '' (nothing) for tones lower than c'
+                  <sup>1</sup> for c'
+                  <sup>2</sup> for c'' etc.
         """
         assert -3 < self.m_accidental_i < 3, self.m_accidental_i
         utnotename = ['c', 'd', 'e', 'f', 'g', 'a', 'b'][self.m_notename_i]\
@@ -316,6 +325,10 @@ class MusicalPitch:
             suboct = "<sub>%s</sub>" % (-self.m_octave_i)
         else:
             suboct = ""
+        if self.m_octave_i < -1:
+            suboct2 = "<sub>%s</sub>" % (-self.m_octave_i-1)
+        else:
+            suboct2 = ""
         if self.m_octave_i > 0:
             supoct = "<sup>%s</sup>" % (self.m_octave_i)
         else:
@@ -324,6 +337,7 @@ class MusicalPitch:
              'notename': notename,
              'notename2': notename2,
              'suboct': suboct,
+             'suboct2': suboct2,
              'supoct': supoct,
              'oct': oct}
         try:
