@@ -43,7 +43,6 @@ from requests import *
 from soundcard.rat import Rat
 import const
 import soundcard
-import types
 import mpdutils
 import _exceptions
 
@@ -147,7 +146,7 @@ class Score:
         self.m_spanner_list = []
         self.m_stem_list = []
         for staff in self.m_staffs:
-            staff.accbarline(("c", "major"))
+            staff.refill_accidentals_info(("c", "major"))
             key = ('c', 'major')
             se = []
             V.append(se)
@@ -209,20 +208,20 @@ class Score:
                        = max(self.m_timeposdict[timepos].m_clef, se[-1].get_width())
                 #key signature
                 if staff.m_coldict[timepos].m_keysignature:
-                    se.append(KeySignatureEngraver(timepos, fontsize,
+                    se.append(KeySignatureEngraver(timepos, fontsize, key,
                                      staff.m_coldict[timepos].m_keysignature, clef))
                     self.m_timeposdict[timepos].m_keysignature \
                        = max(self.m_timeposdict[timepos].m_keysignature,
                              se[-1].get_width())
                     key = staff.m_coldict[timepos].m_keysignature
-                    staff.accbarline(key)
+                    staff.refill_accidentals_info(key)
                 # barline
                 if staff.m_coldict[timepos].m_barline:
                     se.append(BarlineEngraver(timepos, fontsize, "|"))
                     self.m_timeposdict[timepos].m_barline \
                        = max(self.m_timeposdict[timepos].m_barline,
                              se[-1].get_width())
-                    staff.accbarline(key)
+                    staff.refill_accidentals_info(key)
                 # time signature
                 if self.m_timeposdict[timepos].m_timesignature_obj:
                     se.append(TimeSignatureEngraver(timepos, fontsize,
@@ -475,33 +474,34 @@ class Staff:
         voice = Voice(self)
         self.m_voice_list.append(voice)
         return voice
-    def accbarline(self, key):
-        """Do accidental stuff on barline.
+    def refill_accidentals_info(self, key):
+        """Fill the .m_accidentals_info dict with the accidentals
+        that exist in the key signature `key`.
         """
-        self.m_i = {}
+        self.m_accidentals_info = {}
         for step in range(MusicalPitch.LOWEST_STEPS, MusicalPitch.HIGHEST_STEPS+1):
-            self.m_i[step] = 0
+            self.m_accidentals_info[step] = 0
         for a in mpdutils.key_to_accidentals(key):
             n = MusicalPitch.new_from_notename(a)
             for oct in range(-4, 7):
                 n.m_octave_i = oct
                 if n.semitone_pitch() < 128:
                     if a[-4:] == 'eses':
-                        self.m_i[n.steps()] = -2
+                        self.m_accidentals_info[n.steps()] = -2
                     elif a[-2:] == 'es':
-                        self.m_i[n.steps()] = -1
+                        self.m_accidentals_info[n.steps()] = -1
                     elif a[-4:] == 'isis':
-                        self.m_i[n.steps()] = 2
+                        self.m_accidentals_info[n.steps()] = 2
                     else:
-                        self.m_i[n.steps()] = 1
+                        self.m_accidentals_info[n.steps()] = 1
     def needed_accidental(self, m):
         steps = m.steps()
-        if m.m_accidental_i != self.m_i[steps]:
-            if (self.m_i[steps] == 2 and m.m_accidental_i == 1) \
-                    or (self.m_i[steps] == -2 and m.m_accidental_i == -1):
-                self.m_i[steps] = m.m_accidental_i
+        if m.m_accidental_i != self.m_accidentals_info[steps]:
+            if (self.m_accidentals_info[steps] == 2 and m.m_accidental_i == 1) \
+                    or (self.m_accidentals_info[steps] == -2 and m.m_accidental_i == -1):
+                self.m_accidentals_info[steps] = m.m_accidental_i
                 return [0, m.m_accidental_i]
-            self.m_i[steps] = m.m_accidental_i
+            self.m_accidentals_info[steps] = m.m_accidental_i
             return [m.m_accidental_i]
     def barline(self, timepos):
         #assert not self.m_coldict.has_key(timepos)
@@ -799,7 +799,7 @@ def parse_to_score_object(music):
                 tuplet_dir = toc_data
             else:
                 print "*%s*" % toc, type(toc), lexer.m_idx
-                print "music:", music[lexer.m_idx-4:]
+                print "music: '%s'" % music[lexer.m_idx-4:]
                 raise ParseError(toc)
         return score
 
@@ -818,14 +818,14 @@ class Lexer:
     RELATIVE = 11
     TIMES = 12
     TUPLETDIR = 13
-    re_staff = re.compile(r"\s*\\staff")
-    re_voice = re.compile(r"\s*\\addvoice")
-    re_clef = re.compile(r"\s*\\clef\s+(\w*)")
-    re_stem_updown = re.compile(r"\s*(\\stem)(Up|Down|Both)\s+")
-    re_tuplet_updown = re.compile(r"\s*(\\tuplet)(Up|Down|Both)\s+")
-    re_relative = re.compile(r"\s*\\relative\s+(([a-zA-Z]+)([',]*))")
-    re_transpose = re.compile(r"\s*\\transpose\s+(([a-zA-Z]+)([',]*))")
-    re_rest = re.compile(r"\s*(r)([\d]*)(\.*)")
+    re_staff = re.compile(r"\s*\\staff", re.UNICODE)
+    re_voice = re.compile(r"\s*\\addvoice", re.UNICODE)
+    re_clef = re.compile(r"\s*\\clef\s+(\w*)", re.UNICODE)
+    re_stem_updown = re.compile(r"\s*(\\stem)(Up|Down|Both)\s+", re.UNICODE)
+    re_tuplet_updown = re.compile(r"\s*(\\tuplet)(Up|Down|Both)\s+", re.UNICODE)
+    re_relative = re.compile(r"\s*\\relative\s+(([a-zA-Z]+)([',]*))", re.UNICODE)
+    re_transpose = re.compile(r"\s*\\transpose\s+(([a-zA-Z]+)([',]*))", re.UNICODE)
+    re_rest = re.compile(r"\s*(r)([\d]*)(\.*)", re.UNICODE)
         #FIXME we are a little more strict than Lilypond, since ~ has to
         # be before ]
         #FIXME don't use named regex if we don't need it.
@@ -834,16 +834,16 @@ class Lexer:
                              ((?P<notename>[a-zA-Z]+)
                              (?P<octave>[',]*))
                              (?P<len>[\d]*)
-                             (?P<dots>\.*)""")
+                             (?P<dots>\.*)""", re.UNICODE)
     re_skip = re.compile(r"""(?x)
                             \s*
                              (s)
                              (?P<len>[\d]*)
-                             (?P<dots>\.*)""")
-    re_tempo = re.compile(r"\s*\\tempo\s+(\d+)\s*=+s*(\d+);")
-    re_time = re.compile(r"\s*\\time\s+(\d+)\s*/\s*(\d+)")
-    re_key = re.compile(r"\s*\\key\s+([a-z]+)\s*\\(major|minor)")
-    re_times = re.compile(r"\s*\\times\s+(\d+)\s*/\s*(\d+)\s*{")
+                             (?P<dots>\.*)""", re.UNICODE)
+    re_tempo = re.compile(r"\s*\\tempo\s+(\d+)\s*=+s*(\d+);", re.UNICODE)
+    re_time = re.compile(r"\s*\\time\s+(\d+)\s*/\s*(\d+)", re.UNICODE)
+    re_key = re.compile(r"\s*\\key\s+([a-z]+)\s*\\(major|minor)", re.UNICODE)
+    re_times = re.compile(r"\s*\\times\s+(\d+)\s*/\s*(\d+)\s*{", re.UNICODE)
     def __init__(self, s):
         self.m_string = string.strip(s)
         self.m_notelen = Duration(4, 0)
