@@ -13,7 +13,9 @@ p + div > dl {
  margin-top: 0;
  }
 dd { margin-left: 50px; }
-
+dl { margin-bottom: 0px; padding-bottom: 0px; }
+ul { margin-top: 0px; margin-bottom: 0px}
+li p { margin-bottom: 0px; }
 BODY {
   /* FIXME gtkhtml2 like us to give the font-family Sans, because
      it does not seem to know about sans-serif. */
