@@ -54,7 +54,7 @@ exercises = ('chord',
 
 msg1 = _("""Because not all documents has been
 <a href="translating-solfege.html">translated</a>
-to LANGUAGE yet, the links goes to the english version for those
+to LANGUAGE yet, the links go to the english version for those
 untranslated sections.""")
 
 msg2 = ""
@@ -127,8 +127,8 @@ BODY {
     }).encode('UTF-8'))
     for fn in user_docs:
         f.write('\n<dt><a href="%s.html">%s</a></dt>' % (fn, get_title_of_file(fn+'.xml', source_encoding)))
-    f.write('<dt></dt><dd><a href="gpl.html">GPL</a></dd>')
-    f.write('<dt></dt><dd><a href="fdl.html">FDL</a></dd>')
+    f.write('<dt></dt><dd><a href="gpl-appendix.html">GPL</a></dd>')
+    f.write('<dt></dt><dd><a href="fdl-appendix.html">FDL</a></dd>')
     f.write("""
 </dl>
 
