@@ -1,4 +1,4 @@
-#!/usr/bin/python2.2
+#!/usr/bin/python
 
 # GNU Solfege - eartraining for GNOME
 # Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
@@ -37,8 +37,7 @@ import src.rcfile
 src.rcfile.copy_rc_file()
 import src.cfg
 
-src.cfg.initialise(None, "default.config", "~/.solfegerc%i.%i" %
-  (src.configureoutput.MAJOR_VERSION, src.configureoutput.MINOR_VERSION))
+src.cfg.initialise(None, "default.config", "~/.solfegerc")
 
 if '--txtui' in sys.argv:
     import src.txtui
