@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import sys, os, types, tempfile, string, signal
+import sys, os, tempfile, string, signal
 import mfutils
 
 def ms_win_kill(pid):
@@ -85,7 +85,7 @@ class MidiFileSynth:
         notelen = 0
         for e in track.m_v:
             if e[0] == track.TEMPO:
-                v = v + mfutils.mf_tempo(e[1] * e[2] / 4)
+                v = v + mfutils.mf_tempo(e[1] * 4 / e[2])
             elif e[0] == track.NOTELEN_TIME:
                notelen = e[1]
             elif e[0] == track.NOTE_ON:
