@@ -34,6 +34,7 @@ class SolfegeApp(cfg.ConfigUtils):
         self.m_teachers = {}
         self.m_running_exercise = None
         self.lessonfile_manager = lessonfile.LessonFileManager()
+        self.m_sound_init_exception = None
         self.setup_sound()
     def check_rcfile(self):
         if cfg.get_int("app/rcfileversion") > 1:
@@ -75,14 +76,8 @@ the preferences window.
                              cfg.get_string("sound/card_info"),
                              verbose_init='--verbose-sound-init' in self.m_argv)
             except (soundcard.SoundInitException, OSError), e:
-                if e == None:
-                    self.m_ui.display_error_message(
-"""You should configure sound
-from the 'Sound' page of
-the preferences window.
-""")
-                else:
-                    self.display_sound_init_error_message(e)
+                self.m_sound_init_exception = e
+                soundcard.initialise_using_fake_synth(True)
     def display_sound_init_error_message(self, e):
         if isinstance(e, soundcard.SoundInitException):
             self.m_ui.display_error_message(
