@@ -85,6 +85,7 @@ class HTMLWriter(formatter.NullWriter):
         self.m_charset="ascii"
         self.m_link_list = []
         self.m_table = None
+        self._para_is_new = 0
         self.m_ignore_flowing_data = 0
         self.setup_fonts()
         self.g_tw.connect('button-release-event', self.on_button_release)
@@ -134,7 +135,8 @@ class HTMLWriter(formatter.NullWriter):
         if self.m_ignore_flowing_data:
             return
         buf = self.g_tw.get_buffer()
-        txt = unicode(txt, self.m_charset, 'replace')
+        if not isinstance(txt, unicode):
+           txt = txt.decode(self.m_charset, 'replace')
         txt = txt.strip('\n')
         tags = ['normal', '%s-margin%i' % self.m_margin]
         if self.m_link:
@@ -233,6 +235,10 @@ class HTMLWriter(formatter.NullWriter):
             t = b.create_tag('ul-margin%i' % n)
             t.set_property('left-margin', n*20+10)
 
+        for n in range(10):#FIXME numeric constant
+            t = b.create_tag('ol-margin%i' % n)
+            t.set_property('left-margin', n*20+10)
+
 
 class MyHTMLParser(htmllib.HTMLParser):
     def __init__(self, formatter, writer):
