@@ -49,7 +49,6 @@ class SelectLessonfileWidget(gtk.Frame):
         gu.bLabel(hbox, _("Title")+": ", gtk.FALSE)
         self.g_title = gu.bLabel(hbox, "", gtk.FALSE)
 
-        #details
         self.g_toggle_description = gtk.ToggleButton(_("Details"))
         self.g_toggle_description.connect('clicked', self.toggle_lessonfile_details)
         hbox.pack_end(self.g_toggle_description, gtk.FALSE, gtk.FALSE)
@@ -57,46 +56,70 @@ class SelectLessonfileWidget(gtk.Frame):
         self.g_lessonfile_details = HtmlWidget(self.m_t.m_app.handle_href, None)
         self.g_description_frame.add(self.g_lessonfile_details)
         vbox.pack_start(self.g_description_frame)
-        self.m_lock = 0
         self.update()
-        self.g_collection.connect('changed', self.change_collection)
-        self.g_files.connect('changed', self.change_file)
+        self._sc = self._sf = None
+        self.connect_changed_signals()
         self._fw = self.m_t.add_watch('lessonfile', self._lessonfilewatch)
         self._cw = self.m_t.add_watch('lessoncollection', self._lessoncollectionwatch)
+    def connect_changed_signals(self):
+        assert self._sc == self._sf == None
+        self._sc = self.g_collection.connect('changed', self.on_change_collection)
+        self._sf = self.g_files.connect('changed', self.on_change_file)
+    def disconnect_changed_signals(self):
+        assert self._sc
+        assert self._sf
+        self.g_collection.disconnect(self._sc)
+        self.g_files.disconnect(self._sf)
+        self._sc = self._sf = None
     def _lessonfilewatch(self, s):
-        self.m_t.remove_watch('lessonfile', self._fw)
-        self._fw = self.m_t.add_watch('lessonfile', self._lessonfilewatch)
+        self.do_change_file(self.m_t.get_string(s))
+        v = self.m_t.m_app.lessonfile_manager.get_filenames(
+           self.m_t.get_string('lessoncollection'), self.m_t.m_content_type
+           )
+        self.g_files.set_history(v.index(self.m_t.get_string(s)))
     def _lessoncollectionwatch(self, s):
+        self.do_change_collection(self.m_t.get_string(s))
+    def on_change_collection(self, widget=None):
+        collection = self.m_t.m_app.lessonfile_manager.get_collections()[widget.get_history()]
+        self.do_change_collection(collection)
+    def do_change_collection(self, collection):
+        self.disconnect_changed_signals()
+        self.m_t.remove_watch('lessonfile', self._fw)
         self.m_t.remove_watch('lessoncollection', self._cw)
-        self.m_lock = self.m_lock + 1
-        self.m_lock = self.m_lock - 1
-        self._cw = self.m_t.add_watch('lessoncollection', self._lessoncollectionwatch)
-    def change_collection(self, widget):
         try:
-            self.m_t.set_lessoncollection(self.m_t.m_app.lessonfile_manager.get_collections()[widget.get_history()])
+            self.m_t.set_lessoncollection(collection)
         except dataparser.DataparserException, e:
             self.m_ui.display_error_message(str(e))
             self.m_t.m_P = None
         self.update(1)
         self.change_cb()
-    def change_file(self, widget):
-        if self.m_lock > 0:
-            return
+        self._cw = self.m_t.add_watch('lessoncollection', self._lessoncollectionwatch)
+        self._fw = self.m_t.add_watch('lessonfile', self._lessonfilewatch)
+        self.connect_changed_signals()
+    def on_change_file(self, widget):
+        """This function is hooked up to the changed signal for the option menu
+        """
+        new_filename = self.m_t.m_app.lessonfile_manager.get_filenames(
+           self.m_t.get_string('lessoncollection'), self.m_t.m_content_type
+           )[widget.get_history()]
+        self.do_change_file(new_filename)
+    def do_change_file(self, new_filename):
+        self.disconnect_changed_signals()
+        self.m_t.remove_watch('lessonfile', self._fw)
         try:
-            self.m_t.set_lessonfile(self.m_t.m_app.lessonfile_manager.get_filenames(self.m_t.get_string('lessoncollection'), self.m_t.m_content_type)[widget.get_history()])
+            self.m_t.set_lessonfile(new_filename)
         except dataparser.DataparserException, e:
             self.m_ui.display_error_message(str(e))
             self.m_t.m_P = None
         self.update(2)
         self.change_cb()
+        self._fw = self.m_t.add_watch('lessonfile', self._lessonfilewatch)
+        self.connect_changed_signals()
     def update(self, level=0):
         """0: everything
            1: don't include collection combo
            2: only information label
         """
-        if self.m_lock > 0:
-            return
-        self.m_lock += 1
         if level == 0:
             if not self.g_collection.get_menu():
                 menu = gtk.Menu()
@@ -126,12 +149,8 @@ class SelectLessonfileWidget(gtk.Frame):
                     menu.destroy()
                 self.g_files.set_sensitive(gtk.FALSE)
                 self.g_title.set_text('')
-                self.g_description_frame.hide()
-                #self.g_lessonfile_details.source("<html></html>")
-                self.g_toggle_description.set_active(gtk.FALSE)
-                self.g_toggle_description.set_sensitive(gtk.FALSE)
+                self.g_lessonfile_details.source("<html></html>")
         if not self.m_t.m_P:
-            self.m_lock = self.m_lock - 1
             return
         # the info labels
         if self.m_t.m_P:
@@ -141,12 +160,8 @@ class SelectLessonfileWidget(gtk.Frame):
         s = self.m_t.m_P.header.description
         if s:
             self.g_lessonfile_details.source("<html><body bgcolor=white>%s</body></html>" % s)
-            self.g_toggle_description.set_sensitive(gtk.TRUE)
         else:
            self.g_lessonfile_details.source("<html></html>")
-           self.g_toggle_description.set_active(gtk.FALSE)
-           self.g_toggle_description.set_sensitive(gtk.FALSE)
-        self.m_lock = self.m_lock - 1
     def toggle_lessonfile_details(self, widget=None):
         if widget.get_active():
             self.g_description_frame.show()
