@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,15 +18,18 @@
 import gtk, gnome
 import gu, const, soundcard, mpd, mpd.musicdisplayer, abstract
 import lessonfile, string
-from i18n import _
 import widgets
 import utils
+import dataparser
 
 class Teacher(abstract.LessonbasedTeacher):
     def __init__(self, exname, app):
         abstract.LessonbasedTeacher.__init__(self, exname, app, const.USE_SING_CHORD)
         self.lessonfileclass = lessonfile.SingChordLessonfile
-        self.parse_lessonfile()
+        try: # the lessonfile might contain errors.
+            self.parse_lessonfile()
+        except dataparser.DataparserException, e:
+            self.m_app.m_ui.display_error_message(str(e))
     def new_question(self):
         self.q_status = const.QSTATUS_NEW
         self.m_P.select_random_question()
@@ -65,19 +68,16 @@ class Teacher(abstract.LessonbasedTeacher):
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
         abstract.LessonbasedGui.__init__(self, teacher, window)
-        self.m_key_bindings = {'new_ak': self.new_question,
-                               '440hz_ak': self.m_t.play_440hz,
-                               'play_answer_ak': self.m_t.play_answer_arpeggio}
         ################
         # practise_box #
         ################
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
-        self.g_music_displayer.set_usize(-1, 170)
+        self.g_music_displayer.set_size_request(-1, 170)
         self.practise_box.pack_start(self.g_music_displayer)
 
-        self.g_new = gu.bButton(self.action_area, _("New"), self.new_question)
-        gu.bButton(self.action_area, _("440hz"), lambda f, s=self: s.m_t.play_440hz())
-        self.g_play_answer = gu.bButton(self.action_area, _("Play answer"), lambda f, s=self: s.m_t.play_answer_arpeggio())
+        self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
+        gu.bButton(self.action_area, _("440h_z"), lambda f, s=self: s.m_t.play_440hz())
+        self.g_play_answer = gu.bButton(self.action_area, _("_Play answer"), lambda f, s=self: s.m_t.play_answer_arpeggio())
         self.practise_box.show_all()
         ##############
         # config_box #
@@ -88,15 +88,34 @@ class Gui(abstract.LessonbasedGui):
         self.config_box.pack_start(self.g_lessonfile_selector)
         self.update_gui_after_lessonfile_change()
     def new_question(self, widget=None):
-        self.m_t.new_question()
-        fontsize = self.get_int('config/feta_font_size=20')
-        self.g_music_displayer.display(self.m_t.m_P.get_music(), fontsize)
-        self.g_play_answer.set_sensitive(gtk.TRUE)
-        self.m_t.play_440hz()
+        # if we have no lessonfile, then we have no questions.
+        if not self.m_t.m_P:
+            return
+        try:
+            self.m_t.new_question()
+        except mpd.MpdException, e:
+            # since we could not play the new question, it is possible,
+            # if the user are fast, that the last question is still playing.
+            soundcard.synth.stop()
+            self.g_win.display_error_message(
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
+        else:
+            fontsize = self.get_int('config/feta_font_size=20')
+            self.g_music_displayer.display(self.m_t.m_P.get_music(), fontsize)
+            self.g_play_answer.set_sensitive(gtk.TRUE)
+            self.m_t.play_440hz()
+    def on_start_practise(self):
+        # if we have not m_P, then parsing of the lessonfile failed,
+        # and then we have no questions.
+        if not self.m_t.m_P:
+            self.g_new.set_sensitive(gtk.FALSE)
+        else:
+            self.g_new.set_sensitive(gtk.TRUE)
+        self.g_new.grab_focus()
     def on_end_practise(self):
+        self.m_t.end_practise()
         self.g_play_answer.set_sensitive(gtk.FALSE)
         self.g_music_displayer.clear(2)
-        self.m_t.end_practise()
     def update_gui_after_lessonfile_change(self):
         self.g_music_displayer.clear(2)
         if self.m_t.m_P:
