@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,21 +18,21 @@
 import re
 import gtk
 
-class HarmonicProgressionLabel(gtk.GtkHBox):
+class HarmonicProgressionLabel(gtk.HBox):
     """
     This class can parse strings like I-(6,4)V(5,3)-I and can be used
     as button labels.
     """
     def __init__(self, str, align=''):
-        gtk.GtkHBox.__init__(self)
+        gtk.HBox.__init__(self)
         self.show()
         self.set_text(str, align)
     def set_text(self, str, align=''):
-        for o in self.children():
+        for o in self.get_children():
             o.destroy()
         self.m_str = str
         if align == 'center':
-            self.pack_start(gtk.GtkHBox())
+            self.pack_start(gtk.HBox())
         while self.m_str:
             T, A, B = self.get_next_token()
             if T == 'big' or T == 'err':
@@ -43,7 +43,7 @@ class HarmonicProgressionLabel(gtk.GtkHBox):
                 assert T == 'one'
                 self.oneline(A)
         if align == 'center':
-            self.pack_start(gtk.GtkHBox())
+            self.pack_start(gtk.HBox())
         self.show_all()
     def get_next_token(self):
         m_re1 = re.compile("([^\(]+)")
@@ -63,53 +63,53 @@ class HarmonicProgressionLabel(gtk.GtkHBox):
             return "one", m3.groups()[0], None
         return "err"
     def twoline(self, A, B):
-        vbox = gtk.GtkVBox()
-        t1 = gtk.GtkLabel(A)
+        vbox = gtk.VBox()
+        t1 = gtk.Label(A)
         t1.set_name("ProgressionLabelNumber")
         t1.show();vbox.pack_start(t1);
         t1.set_alignment(0, 0);
-        t2 = gtk.GtkLabel(B)
+        t2 = gtk.Label(B)
         t2.set_name("ProgressionLabelNumber")
         t2.show();vbox.pack_start(t2);
         t2.set_alignment(0, 0);
         self.pack_start(vbox, gtk.FALSE)
     def oneline(self, A):
-        vbox = gtk.GtkVBox()
-        t = gtk.GtkLabel(A)
+        vbox = gtk.VBox()
+        t = gtk.Label(A)
         t.set_name("ProgressionLabelNumber")
         t.show();vbox.pack_start(t);
         t.set_alignment(0, 0);
         self.pack_start(vbox, gtk.FALSE)
     def bigchar(self, A):
-        t1 = gtk.GtkLabel(A)
+        t1 = gtk.Label(A)
         t1.set_name("ProgressionNameLabel")
         t1.show()
         self.pack_start(t1, gtk.FALSE)
 
 
-class QuestionNameButtonTable(gtk.GtkTable):
+class QuestionNameButtonTable(gtk.Table):
     """
     In lack of a better name for this class...
-    This gtk.GtkTable extension creates a table width buttons that is added
+    This gtk.Table extension creates a table width buttons that is added
     in an intelligent way, and the labels of the buttons can be normal
     text or chord progression names. See: HarmonicProgressionLabel
     """
     def __init__(self):
-        gtk.GtkTable.__init__(self)
+        gtk.Table.__init__(self)
     def initialize(self, num, dir):
         self.m_num = num
         self.m_dir = dir
         self.m_x = 0
         self.m_y = 0
-        for X in self.children():
+        for X in self.get_children():
             X.destroy()
     def add(self, key, label_code, style, callback):
-        b = gtk.GtkButton()
+        b = gtk.Button()
         b.set_data('pcode', key)
         if style == 'progression':
             b.add(HarmonicProgressionLabel(label_code, 'center'))
-        else:	
-            b.add(gtk.GtkLabel(label_code))
+        else:
+            b.add(gtk.Label(label_code))
         b.show_all()
         self.attach(b, self.m_x, self.m_x+1, self.m_y, self.m_y+1)
         b.connect('clicked', callback)
@@ -123,4 +123,5 @@ class QuestionNameButtonTable(gtk.GtkTable):
             if self.m_x == self.m_num:
                 self.m_x = 0
                 self.m_y = self.m_y + 1
-
+    def grab_focus_first_button(self):
+        self.get_children()[-1].grab_focus()
