@@ -15,15 +15,67 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import sys
+if __name__ == '__main__':
+    import pygtk
+    pygtk.require('2.0')
+    sys.path.append(".")
+
 import time, os, pickle
+import shutil
 import utils
 import configureoutput
 
-STATISTICS_SAVE_DIR = os.path.join(os.path.expanduser('~'),
-       '.solfege%s.%s' % (configureoutput.MAJOR_VERSION, configureoutput.MINOR_VERSION))
-if not os.path.exists(STATISTICS_SAVE_DIR):
-    os.mkdir(STATISTICS_SAVE_DIR)
+# version 1, the first version was introduced with Solfege 2.0
+statistics_version = 1
 
+STATISTICS_SAVE_DIR = os.path.join(os.path.expanduser('~'), '.solfege')
+if not os.path.exists(STATISTICS_SAVE_DIR):
+    for ver in '1.9', '1.4':
+        if os.path.exists(os.path.join(os.path.expanduser('~'), '.solfege%s' % ver)):
+            shutil.copytree(os.path.join(os.path.expanduser('~'), '.solfege%s' % ver),
+                            STATISTICS_SAVE_DIR)
+            break
+    if not os.path.exists(STATISTICS_SAVE_DIR):
+        os.mkdir(STATISTICS_SAVE_DIR)
+    f = file(os.path.join(STATISTICS_SAVE_DIR, 'statistics_version'), 'w')
+    print >> f, statistics_version
+    f.close()
+
+def get_statistics_version():
+    """
+    Return as an int, the version number the statistics stored in
+    STATISTICS_SAVE_DIR has.
+    """
+    try:
+        f = file(os.path.join(STATISTICS_SAVE_DIR, 'statistics_version'), 'r')
+    except IOError, e:
+        print >> sys.stderr, "While opening the file $HOME/.solfege/statistics_version:"
+        print >> sys.stderr, e
+        return 0
+    s = f.read()
+    f.close()
+    try:
+        return int(s)
+    except ValueError, e:
+        print >> sys.stderr, "While parsing the content of $HOME/.solfege/statistics_version:"
+        print >> sys.stderr, e
+        return 0
+
+statistics_on_disk_version = get_statistics_version()
+if statistics_on_disk_version > statistics_version:
+    usable_statistics = None
+    print >> sys.stderr, """The statistics stored in $HOME/.solfege have been created by a newer version of
+Solfege, and that release has changed the way statistics are saved. If you want
+to record statistics, you must either use that newer version of Solfege, or
+delete (or rename) the directory $HOME/.solfege\n"""
+elif statistics_on_disk_version == 0:
+    usable_statistics = None
+    print >> sys.stderr, """
+Something is strange with the statistics stored in $HOME/.solfege.
+"""
+else:
+    usable_statistics = 1
 YEAR = 0
 MONTH = 1
 DAY = 2
@@ -45,8 +97,9 @@ class AbstractStatistics:
                         'last7'   : self.m_last7_stat,
                         'total'   : self.m_total_stat}
         self.m_savepath = os.path.join(STATISTICS_SAVE_DIR, self.m_t.m_exname)
-        if not os.path.exists(self.m_savepath):
-            os.mkdir(self.m_savepath)
+        if usable_statistics:
+            if not os.path.exists(self.m_savepath):
+                os.mkdir(self.m_savepath)
     def _add(self, question, answer):
         for D in [self.m_session_stat, self.m_today_stat,
                   self.m_last7_stat, self.m_total_stat]:
@@ -70,6 +123,8 @@ class AbstractStatistics:
                 A[k][n] = A[k][n] + B[k][n]
         return A
     def load_statistics(self, datadir):
+        if not usable_statistics:
+            return
         for filename in os.listdir(datadir):
             t = int(filename)
             lt = time.localtime(t)
@@ -154,6 +209,8 @@ class Statistics(AbstractStatistics):
         AbstractStatistics.__init__(self, teacher)
         self.load_statistics(self.m_savepath)
     def save_data(self):
+        if not usable_statistics:
+            return
         if self.m_session_stat:
             f = open(os.path.join(self.m_savepath, str(int(time.time()))), 'w')
             pickle.dump(self.m_session_stat, f)
@@ -180,6 +237,8 @@ class LessonStatistics(AbstractStatistics):
         self.m_total_stat = {}
         self.m_cur_collection = new_collection
         self.m_cur_file = new_file
+        if not usable_statistics:
+            return
         self.create_statistics_dir()
 
         # if the lessonfile has changed, we have to
@@ -196,6 +255,8 @@ class LessonStatistics(AbstractStatistics):
                                           self.m_cur_collection,
                                           self.m_cur_file))
     def save_data(self):
+        if not usable_statistics:
+            return
         if self.m_session_stat == {}:
             return
         #save the hashvalue for the lessonfile this statistics was made with
@@ -248,3 +309,5 @@ class HarmonicIntervalStatistics(Statistics):
     def key_to_pretty_name(self, key):
         return utils.int_to_intervalname(key, 1, 0)
 
+if __name__ == '__main__':
+    print "statistics_version:", get_statistics_version()
