@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
 from instrumentselector import InstrumentSelector, InstrumentConfigurator
 from notenamespinbutton import NotenameRangeController, \
                                nNotenameRangeController, \
-                               SimplestNotenameSpinButton
+                               NotenameSpinButton
 from specialwidgets import QuestionNameButtonTable, HarmonicProgressionLabel
-from multipleintervallconfigwidget import MultipleIntervallConfigWidget, \
-                                          IntervallCheckBox
+from multipleintervalconfigwidget import MultipleIntervalConfigWidget, \
+                                          IntervalCheckBox
 from selectlessonfilewidget import SelectLessonfileWidget
