@@ -3,7 +3,7 @@
 import pygtk
 pygtk.require("2.0")
 import profile, os
-import types, sys
+import sys
 if len(sys.argv) < 2:
     print "\nUsage: ./test/lessonparser-test.py lessonfile-to-test\n"
     sys.exit()
