@@ -1,11 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/python2.2
 import sys, os
 if os.getcwd()[-4:] == "test":
     sys.path.insert(0, "..")
 else:
     sys.path.insert(0, ".")
 import soundcard
-soundcard.initialise("/dev/music", 0)
+soundcard.initialise_devicefile("/dev/music", 0)
 #soundcard.initialise("/dev/sequencer", 0)
 s = soundcard.solfege_c_midi
 
